==> eslint-plugin-jsx-a11y-0.4.1.tgz: package/lib/rules/onclick-uses-role.js <==
/**
 * @fileoverview Enforce non-interactive elements with
 *  click handlers use role attribute.
 * @author Ethan Cohen
 */
'use strict';

var _isHiddenFromScreenReader = require('../util/isHiddenFromScreenReader');

var _isHiddenFromScreenReader2 = _interopRequireDefault(_isHiddenFromScreenReader);

var _isInteractiveElement = require('../util/isInteractiveElement');

var _isInteractiveElement2 = _interopRequireDefault(_isInteractiveElement);

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var errorMessage = 'Visible, non-interactive elements with click handlers must ' + 'have role attribute.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var attributes = node.attributes;
      if ((0, _hasAttribute2.default)(attributes, 'onclick') === false) {
        return;
      }

      var isVisible = (0, _isHiddenFromScreenReader2.default)(attributes) === false;
      var isNonInteractive = (0, _isInteractiveElement2.default)(node.name.name, attributes) === false;
      var noRoleAttribute = (0, _hasAttribute2.default)(attributes, 'role') === false;

      // Visible, non-interactive elements require role attribute.
      if (isVisible && isNonInteractive && noRoleAttribute) {
        context.report({
          node: node,
          message: errorMessage
        });
      }
    }
  };
};

module.exports.schema = [{ type: 'object' }];

==> eslint-plugin-jsx-a11y-0.4.3.tgz: package/lib/rules/onclick-uses-role.js <==
/**
 * @fileoverview Enforce non-interactive elements with
 *  click handlers use role attribute.
 * @author Ethan Cohen
 */
'use strict';

var _isHiddenFromScreenReader = require('../util/isHiddenFromScreenReader');

var _isHiddenFromScreenReader2 = _interopRequireDefault(_isHiddenFromScreenReader);

var _isInteractiveElement = require('../util/isInteractiveElement');

var _isInteractiveElement2 = _interopRequireDefault(_isInteractiveElement);

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

var _getNodeType = require('../util/getNodeType');

var _getNodeType2 = _interopRequireDefault(_getNodeType);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var errorMessage = 'Visible, non-interactive elements with click handlers must ' + 'have role attribute.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var attributes = node.attributes;
      if ((0, _hasAttribute2.default)(attributes, 'onclick') === false) {
        return;
      }

      var isVisible = (0, _isHiddenFromScreenReader2.default)(attributes) === false;
      var isNonInteractive = (0, _isInteractiveElement2.default)((0, _getNodeType2.default)(node), attributes) === false;
      var noRoleAttribute = (0, _hasAttribute2.default)(attributes, 'role') === false;

      // Visible, non-interactive elements require role attribute.
      if (isVisible && isNonInteractive && noRoleAttribute) {
        context.report({
          node: node,
          message: errorMessage
        });
      }
    }
  };
};

module.exports.schema = [{ type: 'object' }];
